@@ -14,29 +14,137 @@ CAS.checksum <- function(CAS.string)
 }
 
 
-augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,value,species=NULL,reference,overwrite=F)
+#' Add a paramter value to the chem.physical_and_invitro.data table
+#' 
+#' This internal function is used by \code{\link{add_chemtable}} to add a single 
+#' new parameter to the table of chemical parameters. It should not be typically
+#' used from the command line.
+#' 
+#' @param this.table Object of class data.frame containing one row per chemical.
+#' 
+#' @param this.CAS The Chemical Abstracts Service registry number (CAS-RN)
+#' correponding to the parameter value
+#'
+#' @param compound.name A name associated with the chemical (defaults to NULL)
+#'
+#' @param this.property The property being added/modified.
+#'
+#' @param value The value being assigned to this.property.
+#'
+#' @param reference This is the reference for the data in the new table. This
+#' may be omitted if a column in data.list gives the reference value for each
+#' chemical.
+#'
+#' @param species This is the species for the data in the new table. This may
+#' be omitted if a column in data.list gives the species value for each
+#' chemical or if the data are not species-specific (e.g., MW).
+#'
+#' @param overwrite If overwrite=TRUE then data in current.table will be
+#' replaced by any data in new.table that is for the same chemical and
+#' property. If overwrite=FALSE (DEFAULT) then new data for the same chemical
+#' and property are ignored.  Funbound.plasma values of 0 (below limit of
+#' detection) are overwritten either way.
+#' 
+#' @param sig.fig Sets the number of significant figures stored (defaults to 4)
+#' 
+#' @param clint.pvalue.overwrite If TRUE then the Cl_int p-value is set to NA 
+#' when the Cl_int value is changed unless a new p-value is provided. (defaults
+#' to TRUE) 
+#' 
+#' @param allow.na If TRUE (default is FALSE) then NA values are written to the
+#' table, otherwise they are ignored.
+#'
+#' @return \item{data.frame}{A new data.frame containing the data in
+#' current.table augmented by new.table} 
+#' @author John Wambaugh
+augment.table <- function(
+  this.table,
+  this.CAS,
+  compound.name=NULL,
+  this.property,
+  value,
+  species=NULL,
+  reference,
+  overwrite=F,
+  sig.fig = 4,
+  clint.pvalue.overwrite=T,
+  allow.na=F)
 {
   # Columns stored in chem.phys_and_invitro.table:
-  CHEM.ID.COLS<-c("Compound","CAS","CAS.Checksum","DTXSID","Formula","SMILES.desalt")
-  CHEM.PHYS.COLS<-c("MW","logP","logPwa","logHenry","logVP","logWSol","MP","pKa_Donor","pKa_Accept","logMA")
-  # The colmuns have "[SPECIES]." prepended to their name:
-  CHEM.INVITRO.COLS <- c("Clint","Clint.pValue","Funbound.plasma","Fgutabs","Rblood2plasma","Caco2.Pab")
+  CHEM.ID.COLS<-c(
+    "Compound",
+    "CAS",
+    "CAS.Checksum",
+    "DTXSID",
+    "Formula",
+    "SMILES.desalt")
+  CHEM.PHYS.COLS<-c(
+    "MW",
+    "logP",
+    "logPwa",
+    "logHenry",
+    "logVP",
+    "logWSol",
+    "MP",
+    "pKa_Donor",
+    "pKa_Accept",
+    "logMA")
+  # These colmuns have "[SPECIES]." prepended to their name:
+  CHEM.INVITRO.COLS <- c(
+    "Clint",
+    "Clint.pValue",
+    "Funbound.plasma",
+    "Fgutabs",
+    "Rblood2plasma"
+    ,"Caco2.Pab")
   # In the table we create, each word in most column names is capitalized:
-  COLUMN.CAPITALIZATION.EXCEPTIONS <- c("Clint.pValue","logP","logMA","logPwa","logHenry","logWSol","MP",
-                                        "MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept",
-                                        "SMILES.desalt","DTXSID","Formula","Caco2.Pab")
+  COLUMN.CAPITALIZATION.EXCEPTIONS <- c(
+    "Clint.pValue",
+    "logP",
+    "logMA",
+    "logPwa",
+    "logHenry",
+    "logWSol",
+    "MP",
+    "MW",
+    "CAS",
+    "CAS.Checksum",
+    "pKa_Donor",
+    "pKa_Accept",
+    "SMILES.desalt",
+    "DTXSID",
+    "Formula",
+    "Caco2.Pab")
   # Many data are converted to numeric,but sometimes we want to preserve strings:
-  AS.NUMERIC.EXCEPTIONS <- c("pKa_Donor","pKa_Accept","SMILES.desalt","Funbound.plasma","Clint","DTXSID","SMILES.desalt","Formula", "Caco2.Pab")
-  if (!is.na(value))
+  AS.NUMERIC.EXCEPTIONS <- c(
+    "pKa_Donor",
+    "pKa_Accept",
+    "SMILES.desalt",
+    "Funbound.plasma",
+    "Clint",
+    "DTXSID",
+    "SMILES.desalt",
+    "Formula",
+    "Caco2.Pab")
+  
+  if (!is.na(value)) if (value == "") value <- NA
+  if (!is.na(value) | allow.na)
   {
-    if (tolower(this.property) %in% tolower(COLUMN.CAPITALIZATION.EXCEPTIONS)) this.property <- COLUMN.CAPITALIZATION.EXCEPTIONS[tolower(COLUMN.CAPITALIZATION.EXCEPTIONS)==tolower(this.property)]
-    else {
+    if (tolower(this.property) %in% tolower(COLUMN.CAPITALIZATION.EXCEPTIONS))
+    {
+      this.property <- COLUMN.CAPITALIZATION.EXCEPTIONS[
+        tolower(COLUMN.CAPITALIZATION.EXCEPTIONS)==tolower(this.property)]
+    } else {
       this.property <- tolower(this.property)
       substring(this.property,1,1) <- toupper(substring(this.property,1,1))
     }
   
-                                       
-    data.cols <- c("Reference","Species",CHEM.ID.COLS,CHEM.PHYS.COLS,CHEM.INVITRO.COLS)
+    data.cols <- c(
+      "Reference",
+      "Species",
+      CHEM.ID.COLS,
+      CHEM.PHYS.COLS,
+      CHEM.INVITRO.COLS)
     if (!(tolower(this.property) %in% tolower(data.cols)))
       stop(paste("Parameter", this.property,
         "not matched by columns in our data table."))
@@ -54,7 +162,7 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
       substring(compound.name,1,1) <- toupper(substring(compound.name,1,1))
       compound.name <- iconv(compound.name, from="UTF-8", to='ASCII//TRANSLIT')
     } else {
-  
+      compound.name <- this.CAS
     }
   
     this.property.nospecies <- this.property
@@ -97,19 +205,27 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
     index <- which(this.table[,"CAS"]==this.CAS)
     if (!is.null(compound.name))
     {
-      if (!(compound.name %in% strsplit(this.table[index,"All.Compound.Names"],"[|]")[[1]]))
+      if (!(compound.name %in% 
+        strsplit(this.table[index,"All.Compound.Names"],"[|]")[[1]]))
       {
-        this.table[index,"All.Compound.Names"] <- paste(this.table[index,"All.Compound.Names"],compound.name,sep="|")
+        this.table[index,"All.Compound.Names"] <- 
+          paste(this.table[index,"All.Compound.Names"],compound.name,sep="|")
       }
     }
     if (!is.null(species))
     {
       if (this.property %in% paste(species,CHEM.INVITRO.COLS,sep="."))
       {
-        if (!(species %in% strsplit(this.table[index,"All.Species"],"[|]")[[1]]))
+        if (!(species %in% 
+          strsplit(this.table[index,"All.Species"],"[|]")[[1]]))
         {
-          if (this.table[index,"All.Species"]=="None") this.table[index,"All.Species"] <- species
-          else this.table[index,"All.Species"] <- paste(this.table[index,"All.Species"],species,sep="|")
+          if (this.table[index,"All.Species"]=="None") 
+          {
+            this.table[index,"All.Species"] <- species
+          } else {
+            this.table[index,"All.Species"] <- 
+              paste(this.table[index,"All.Species"],species,sep="|")
+          }
         }
       }
     }
@@ -119,24 +235,56 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
       ref.name <- paste(this.property,"Reference",sep=".")
       this.table[,ref.name] <- NA
     }
-    if (is.na(this.table[index,this.property]) | overwrite | (this.property == paste(species,'Funbound.plasma',sep=".") & this.table[index,this.property] == 0))
+    if (is.na(this.table[index,this.property]) | 
+      overwrite | 
+      (this.property == paste(species,'Funbound.plasma',sep=".") & 
+        this.table[index,this.property] == 0))
     {
-      if (!(this.property.nospecies %in% AS.NUMERIC.EXCEPTIONS)) this.table[index,this.property] <- as.numeric(value)
-      else {
+      if (!(this.property.nospecies %in% AS.NUMERIC.EXCEPTIONS))
+      {
+        this.table[index,this.property] <- signif(as.numeric(value), sig.fig)
+      } else {
         if (class(this.table[,this.property])!='character')
         {  
           this.table[,this.property] < as.character(this.table[,this.property])
         }
+# Check to see if this is actually a number and we can use sig figs:        
+        if (!is.na(as.numeric(value)))
+        {
+          if (as.character(as.numeric(value)) == as.character(value))
+          {
+            value <- signif(as.numeric(value), sig.fig)
+          }
+        }
         this.table[index,this.property] <- as.character(value)
       }
+# If Clint is changed, the Clint.pvalue should usually be eliminated:
+      if (this.property.nospecies == "Clint" & clint.pvalue.overwrite)
+      {
+        this.table[index,paste(this.property,".pValue",sep="")] <- NA
+        this.table[index,paste(this.property,".pValue.Reference",sep="")] <- NA
+      }
 # There is a difference between no pKa prediction available, a prediciton of no pKa:
-      if(!is.na(this.table[index,this.property]) & this.table[index,this.property] == "" & this.property %in% c("pKa_Donor","pKa_Accept")) this.table[index,this.property] <- NA
+      if(!is.na(this.table[index,this.property]) & 
+        this.table[index,this.property] == "" & 
+        this.property %in% c("pKa_Donor","pKa_Accept"))
+      {
+        this.table[index,this.property] <- NA
+      }
       ref.name <- paste(this.property,"Reference",sep=".")
       this.table[index,ref.name] <- reference
     }
-    CHEM.PHYS.COLS <- sort(c(CHEM.PHYS.COLS,paste(CHEM.PHYS.COLS,"Reference",sep=".")))
-    col.order <- c(CHEM.ID.COLS[CHEM.ID.COLS %in% colnames(this.table)],"All.Compound.Names",CHEM.PHYS.COLS[CHEM.PHYS.COLS %in% colnames(this.table)],"All.Species")
-    col.order <- c(col.order,sort(colnames(this.table)[!(colnames(this.table) %in% col.order)]))
+    CHEM.PHYS.COLS <- sort(c(
+      CHEM.PHYS.COLS,
+      paste(CHEM.PHYS.COLS,"Reference",sep=".")))
+    col.order <- c(
+      CHEM.ID.COLS[CHEM.ID.COLS %in% colnames(this.table)],
+      "All.Compound.Names",
+      CHEM.PHYS.COLS[CHEM.PHYS.COLS %in% colnames(this.table)],
+      "All.Species")
+    col.order <- c(
+      col.order,
+      sort(colnames(this.table)[!(colnames(this.table) %in% col.order)]))
     
     if (any(is.na(this.table[,"All.Species"]))) browser()
     return(this.table[,col.order])
@@ -157,24 +305,39 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
 #' 
 #' @param new.table Object of class data.frame containing one row per chemical,
 #' with each chemical minimally described by a CAS number.
+#' 
 #' @param data.list This list identifies which properties are to be read from
 #' the table. Each item in the list should point to a column in the table
 #' new.table. Valid names in the list are: 'Compound', 'CAS', 'DSSTox.GSID'
 #' 'SMILES.desalt', 'Reference', 'Species', 'MW', 'logP', 'pKa_Donor',
 #' 'pKa_Accept', 'logMA', 'Clint', 'Clint.pValue', 'Funbound.plasma',
 #' 'Fgutabs', 'Rblood2plasma'.
+#' 
 #' @param current.table This is the table to which data are being added.
+#' 
 #' @param reference This is the reference for the data in the new table. This
 #' may be omitted if a column in data.list gives the reference value for each
 #' chemical.
+#' 
 #' @param species This is the species for the data in the new table. This may
 #' be omitted if a column in data.list gives the species value for each
 #' chemical or if the data are not species-specific (e.g., MW).
+#' 
 #' @param overwrite If overwrite=TRUE then data in current.table will be
 #' replaced by any data in new.table that is for the same chemical and
 #' property. If overwrite=FALSE (DEFAULT) then new data for the same chemical
 #' and property are ignored.  Funbound.plasma values of 0 (below limit of
 #' detection) are overwritten either way.
+#' 
+#' @param sig.fig Sets the number of significant figures stored (defaults to 4)
+#' 
+#' @param clint.pvalue.overwrite If TRUE then the Cl_int p-value is set to NA 
+#' when the Cl_int value is changed unless a new p-value is provided. (defaults
+#' to TRUE) 
+#'
+#' @param allow.na If TRUE (default is FALSE) then NA values are written to the
+#' table, otherwise they are ignored.
+#'
 #' @return \item{data.frame}{A new data.frame containing the data in
 #' current.table augmented by new.table} 
 #' @author John Wambaugh
@@ -207,8 +370,16 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
 #' calc_css(chem.name="B")                                
 #' 
 #' @export add_chemtable
-add_chemtable <- function(new.table, data.list, current.table=NULL, reference=NULL,
-                          species=NULL, overwrite=F)
+add_chemtable <- function(
+  new.table, 
+  data.list, 
+  current.table=NULL, 
+  reference=NULL,
+  species=NULL, 
+  overwrite=F,
+  sig.fig = 4,
+  clint.pvalue.overwrite=T,
+  allow.na=F)
 {
 # Let's make the capitalization consistent in data.list:
   exceptions <- c("Clint.pValue","logP","logPwa","logMA","logHenry","logWSol","MP","MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept","SMILES.desalt","DTXSID","Formula","Caco2.Pab")
@@ -263,14 +434,18 @@ columns in \"data.list\".")
     {
       if (!(data.list[[this.data]] %in% colnames(new.table))) stop(paste(data.list[[this.data]],
         "is not a column in the new table."))
-      current.table <- augment.table(current.table,
-                                     this.CAS,
-                                     this.compound,
-                                     this.property=this.data,
-                                     value=new.table[this.row, data.list[[this.data]]],
-                                     reference=this.reference,
-                                     species=this.species,
-                                     overwrite=overwrite)
+      current.table <- augment.table(
+        current.table,
+        this.CAS,
+        this.compound,
+        this.property=this.data,
+        value=new.table[this.row, data.list[[this.data]]],
+        reference=this.reference,
+        species=this.species,
+        overwrite=overwrite,
+        sig.fig=sig.fig,
+        clint.pvalue.overwrite=clint.pvalue.overwrite,
+        allow.na=allow.na)
     }
   }
 
