@@ -8,7 +8,7 @@
 #' must be specified.
 #' @param chem.cas Either the chemical name, CAS number, or the parameters must
 #' be specified.
-#' @param dtxsid EPA's DSSTox Structure ID (\url{http://comptox.epa.gov/dashboard})  
+#' @param dtxsid EPA's DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human"). 
@@ -272,7 +272,7 @@ calc_hep_clearance <- function(chem.name=NULL,
 #' must be specified.
 #' @param chem.cas Either the chemical name, CAS number, or the parameters must
 #' be specified.
-#' @param dtxsid EPA's DSSTox Structure ID (\url{http://comptox.epa.gov/dashboard})  
+#' @param dtxsid EPA's DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human"). 
@@ -325,6 +325,7 @@ calc_hepatic_clearance <- function(chem.name=NULL,
                                adjusted.Funbound.plasma=T,
                                ...)
 {
+  warning("Function \"calc_hepatic_clearance\" has been renamed to \"calc_hep_clearance\".")
   return(calc_hep_clearance(chem.name=chem.name,
                                chem.cas=chem.cas,
                                dtxsid = dtxsid,
