@@ -56,7 +56,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
   chem.name <- out$chem.name
   
   cat("<?xml version=\"1.0\" encoding=\"UTF-8\"?>
-<sbml xmlns = \"http://www.sbml.org/sbml/level2/version4\" level = \"2\" version = \"4\">
+<sbml xmlns = \"https://www.sbml.org/sbml/level2/version4\" level = \"2\" version = \"4\">
    <model id = \"cell\">
       <listOfCompartments>
          <compartment id = \"compartment\" size = \"1\"/>
@@ -106,7 +106,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Agut\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -133,7 +133,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Agut\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <times/>
                      <ci>
@@ -155,7 +155,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aart\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -200,7 +200,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Alung\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -227,7 +227,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Arest\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -254,7 +254,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aven\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -299,7 +299,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aliver\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -326,7 +326,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Ametabolized\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -359,7 +359,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aliver\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -404,7 +404,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aven\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -455,7 +455,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Akidney\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -482,7 +482,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Atubules\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
@@ -515,7 +515,7 @@ export_pbtk_sbml <- function(chem.cas=NULL,
                <speciesReference species = \"Aven\" stoichiometry = \"1\"/>
             </listOfProducts>
             <kineticLaw>
-               <math xmlns = \"http://www.w3.org/1998/Math/MathML\">
+               <math xmlns = \"https://www.w3.org/1998/Math/MathML\">
                   <apply>
                      <divide/>
                      <apply>
